==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/gui/entity/maid/MaidTabs.java <==
package com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid;

import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.backpack.IBackpackContainerScreen;
import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.config.MaidConfigContainerGui;
import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.task.MaidTaskConfigGui;
import com.github.tartaricacid.touhoulittlemaid.client.gui.widget.button.MaidTabButton;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.TabIndex;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.AbstractMaidContainer;
import com.github.tartaricacid.touhoulittlemaid.network.message.ToggleTabPackage;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;

public class MaidTabs<T extends AbstractMaidContainer> {
    private final int entityId;
    private final int leftPos;
    private final int topPos;

    public MaidTabs(int entityId, int leftPos, int topPos) {
        this.entityId = entityId;
        this.leftPos = leftPos;
        this.topPos = topPos;
    }

    public MaidTabButton[] getTabs(AbstractMaidContainerGui<T> screen) {
        MaidTabButton main = new MaidTabButton(leftPos + 94, topPos + 5, 107, "main",
                (b) -> ClientPlayNetworking.send(new ToggleTabPackage(entityId, TabIndex.MAIN)));
        if (screen instanceof IBackpackContainerScreen) {
            main.field_22763 = false;
        }

        MaidTabButton taskConfig = new MaidTabButton(leftPos + 119, topPos + 5, 132, "task_config",
                (b) -> ClientPlayNetworking.send(new ToggleTabPackage(entityId, TabIndex.TASK_CONFIG)));
        if (screen instanceof MaidTaskConfigGui<?>) {
            taskConfig.field_22763 = false;
        }

        MaidTabButton maidConfig = new MaidTabButton(leftPos + 144, topPos + 5, 157, "maid_config",
                (b) -> ClientPlayNetworking.send(new ToggleTabPackage(entityId, TabIndex.MAID_CONFIG)));
        if (screen instanceof MaidConfigContainerGui) {
            maidConfig.field_22763 = false;
        }

        return new MaidTabButton[]{main, taskConfig, maidConfig};
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.1-neo1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/gui/entity/maid/MaidTabs.java <==
package com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid;

import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.backpack.IBackpackContainerScreen;
import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.config.MaidAIChatConfigContainerGui;
import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.config.MaidConfigContainerGui;
import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.task.MaidTaskConfigGui;
import com.github.tartaricacid.touhoulittlemaid.client.gui.widget.button.MaidTabButton;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.TabIndex;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.AbstractMaidContainer;
import com.github.tartaricacid.touhoulittlemaid.network.message.ToggleTabPackage;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;

public class MaidTabs<T extends AbstractMaidContainer> {
    private final int entityId;
    private final int leftPos;
    private final int topPos;

    public MaidTabs(int entityId, int leftPos, int topPos) {
        this.entityId = entityId;
        this.leftPos = leftPos;
        this.topPos = topPos;
    }

    public MaidTabButton[] getTabs(AbstractMaidContainerGui<T> screen) {
        MaidTabButton main = new MaidTabButton(leftPos + 94, topPos + 5, 107, "main",
                (b) -> ClientPlayNetworking.send(new ToggleTabPackage(entityId, TabIndex.MAIN)));
        if (screen instanceof IBackpackContainerScreen) {
            main.field_22763 = false;
        }

        MaidTabButton taskConfig = new MaidTabButton(leftPos + 119, topPos + 5, 132, "task_config",
                (b) -> ClientPlayNetworking.send(new ToggleTabPackage(entityId, TabIndex.TASK_CONFIG)));
        if (screen instanceof MaidTaskConfigGui<?>) {
            taskConfig.field_22763 = false;
        }

        MaidTabButton maidConfig = new MaidTabButton(leftPos + 144, topPos + 5, 157, "maid_config",
                (b) -> ClientPlayNetworking.send(new ToggleTabPackage(entityId, TabIndex.MAID_CONFIG)));
        if (screen instanceof MaidConfigContainerGui) {
            maidConfig.field_22763 = false;
        }

        MaidTabButton maidAIChatConfig = new MaidTabButton(leftPos + 169, topPos + 5, 182, "maid_ai_chat_config",
                (b) -> ClientPlayNetworking.send(new ToggleTabPackage(entityId, TabIndex.MAID_AI_CHAT_CONFIG)));
        if (screen instanceof MaidAIChatConfigContainerGui) {
            maidAIChatConfig.field_22763 = false;
        }

        return new MaidTabButton[]{main, taskConfig, maidConfig, maidAIChatConfig};
    }
}
